@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: hastache
 version: 0.6.1
-id: hastache-0.6.1-98cda3164df6aeeec7ce348b687c9c91
-key: hasta_493qV9lVYIr24sveFVz7b4
+id: hastache-0.6.1-7d906c00c2beceb84304bd43ff83230a
+key: hasta_1zJTmdbakC7DaTwCJUfyVe
 license: BSD3
 copyright: Sergey S Lymar (c) 2011-2014
 maintainer: Daniil Frumin <dan at covariant.me>
@@ -23,10 +23,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/hastache-0.6.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/hastache-0.6.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/hastache-0.6.1
-hs-libraries: HShastache-0.6.1-493qV9lVYIr24sveFVz7b4
+hs-libraries: HShastache-0.6.1-1zJTmdbakC7DaTwCJUfyVe
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
+    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
@@ -34,7 +34,7 @@ depends:
     ieee754-0.7.6-8a16b174e206384f3f621aa79d33ab8f
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-hastache/html/hastache.haddock
 haddock-html: /usr/share/doc/haskell-hastache/html
